Feodo Tracker | Browse Botnet C&Cs
Description: Browse TrickBot, Dridex and Emotet/Heodo botnet C&Cs identified by Feodo Tracker
Keywords: abuse.ch, malware, botnets, ioc, list, botnet, tracker, feodo, heodo, emotet, browse, dridex, trickbot

# Browse Botnet C&Cs

Here you can browse the list of botnet Command&Control servers (C&Cs) tracked by Feodo Tracker, associated with Dridex and Emotet (aka Heodo). When Feodo Tracker was launched in 2010, it was meant to track Feodo botnet C&Cs. However, Feodo evolved further and different piece of malware of Feodo appeared:

- Emotet: is a successor of the Geodo It first appeared in March 2017 and is also known as Heodo). While it was initially used to commit ebanking fraud, it later turned over to a Pay-Per-Install (PPI)-like botnet which is propagating itself through compromised email credentials. More information about Emotet is available on Malpedia
- TrickBot: has no code base with Emotet. However, TrickBot usually gets dropped by Emotet for lateral movement and to drop additional malware (such as Ryuk ransomware). More information about TrickBot is available on Malpedia
- Dridex: is a successor of the Cridex ebanking Trojan. It first appeared in 2011 and is still very active as of today. There are speculations that the botnet masters behind the ebanking Trojan Dyre moved their operation over to Dridex. More information about Dridex is available on Malpedia

Filter for: Emotet (aka Heodo) TrickBot Dridex

normal